Data Stream Endpoints
=====================

Create a ListenKey (USER_STREAM)
--------------------------------
.. autofunction:: binance.spot.Spot.new_listen_key

Ping/Keep-alive a ListenKey (USER_STREAM)
-----------------------------------------
.. autofunction:: binance.spot.Spot.renew_listen_key

Close a ListenKey (USER_STREAM)
-------------------------------
.. autofunction:: binance.spot.Spot.close_listen_key

Create a margin ListenKey (USER_STREAM)
---------------------------------------
.. autofunction:: binance.spot.Spot.new_margin_listen_key

Renew a margin ListenKey (USER_STREAM)
--------------------------------------
.. autofunction:: binance.spot.Spot.renew_margin_listen_key

Close a margin ListenKey (USER_STREAM)
--------------------------------------
.. autofunction:: binance.spot.Spot.close_margin_listen_key

Create an isolated margin ListenKey (USER_STREAM)
-------------------------------------------------
.. autofunction:: binance.spot.Spot.new_isolated_margin_listen_key

Renew an isolated ListenKey (USER_STREAM)
-----------------------------------------
.. autofunction:: binance.spot.Spot.renew_isolated_margin_listen_key

Close an isolated margin ListenKey (USER_STREAM)
------------------------------------------------
.. autofunction:: binance.spot.Spot.close_isolated_margin_listen_key
